==> cryptocom-exchange-0.8.1.tar.gz: cryptocom-exchange-0.8.1/src/cryptocom/exchange/coins.py <==
from .structs import Coin

AAVE = Coin("AAVE")
ADA = Coin("ADA")
ALGO = Coin("ALGO")
ANKR = Coin("ANKR")
ATOM = Coin("ATOM")
AUDIO = Coin("AUDIO")
AVAX = Coin("AVAX")
BAL = Coin("BAL")
BAND = Coin("BAND")
BAT = Coin("BAT")
BCH = Coin("BCH")
BNT = Coin("BNT")
BOSON = Coin("BOSON")
BTC = Coin("BTC")
CELR = Coin("CELR")
CHR = Coin("CHR")
CHZ = Coin("CHZ")
COMP = Coin("COMP")
CRO = Coin("CRO")
CRV = Coin("CRV")
DAI = Coin("DAI")
DOGE = Coin("DOGE")
DOT = Coin("DOT")
EGLD = Coin("EGLD")
ENJ = Coin("ENJ")
EOS = Coin("EOS")
ETC = Coin("ETC")
ETH = Coin("ETH")
FIL = Coin("FIL")
FLOW = Coin("FLOW")
GRT = Coin("GRT")
HOT = Coin("HOT")
ICX = Coin("ICX")
KAVA = Coin("KAVA")
KNC = Coin("KNC")
KSM = Coin("KSM")
LINK = Coin("LINK")
LRC = Coin("LRC")
LTC = Coin("LTC")
MANA = Coin("MANA")
MATIC = Coin("MATIC")
MCO = Coin("MCO")
MKR = Coin("MKR")
NEAR = Coin("NEAR")
NEO = Coin("NEO")
NKN = Coin("NKN")
OCEAN = Coin("OCEAN")
OGN = Coin("OGN")
OMG = Coin("OMG")
ONE = Coin("ONE")
ONEINCH = Coin("1INCH")
ONT = Coin("ONT")
PAXG = Coin("PAXG")
QTUM = Coin("QTUM")
RARI = Coin("RARI")
REN = Coin("REN")
RLY = Coin("RLY")
RSR = Coin("RSR")
RVN = Coin("RVN")
SAND = Coin("SAND")
SKL = Coin("SKL")
SNX = Coin("SNX")
SOL = Coin("SOL")
STORJ = Coin("STORJ")
STX = Coin("STX")
SUSHI = Coin("SUSHI")
THETA = Coin("THETA")
UMA = Coin("UMA")
UNI = Coin("UNI")
USDC = Coin("USDC")
USDT = Coin("USDT")
VET = Coin("VET")
VTHO = Coin("VTHO")
WAVE = Coin("WAVE")
WAVES = Coin("WAVES")
WBTC = Coin("WBTC")
XLM = Coin("XLM")
XRP = Coin("XRP")
XTZ = Coin("XTZ")
YFI = Coin("YFI")
ZIL = Coin("ZIL")
ZRX = Coin("ZRX")


def all():
    return [
        value for name, value in globals().items()
        if isinstance(value, Coin)
    ]

==> cryptocom-exchange-0.9.2.tar.gz: cryptocom-exchange-0.9.2/src/cryptocom/exchange/coins.py <==
from .structs import Coin

AAVE = Coin("AAVE")
ADA = Coin("ADA")
AGLD = Coin("AGLD")
ALGO = Coin("ALGO")
ALICE = Coin("ALICE")
AMP = Coin("AMP")
ANKR = Coin("ANKR")
AR = Coin("AR")
ATOM = Coin("ATOM")
AUDIO = Coin("AUDIO")
AVAX = Coin("AVAX")
AXS = Coin("AXS")
BAL = Coin("BAL")
BAND = Coin("BAND")
BAT = Coin("BAT")
BCH = Coin("BCH")
BNT = Coin("BNT")
BOSON = Coin("BOSON")
BRZ = Coin("BRZ")
BTC = Coin("BTC")
BUSD = Coin("BUSD")
C98 = Coin("C98")
CELR = Coin("CELR")
CHR = Coin("CHR")
CHZ = Coin("CHZ")
CKB = Coin("CKB")
COMP = Coin("COMP")
COTI = Coin("COTI")
CQT = Coin("CQT")
CRO = Coin("CRO")
CRV = Coin("CRV")
CSPR = Coin("CSPR")
CTSI = Coin("CTSI")
DAI = Coin("DAI")
DERC = Coin("DERC")
DOGE = Coin("DOGE")
DOT = Coin("DOT")
DYDX = Coin("DYDX")
EFI = Coin("EFI")
EGLD = Coin("EGLD")
ENJ = Coin("ENJ")
EOS = Coin("EOS")
ETC = Coin("ETC")
ETH = Coin("ETH")
FARM = Coin("FARM")
FET = Coin("FET")
FIL = Coin("FIL")
FLOW = Coin("FLOW")
FORTH = Coin("FORTH")
FTM = Coin("FTM")
FXS = Coin("FXS")
GHST = Coin("GHST")
GRT = Coin("GRT")
GTC = Coin("GTC")
GUSD = Coin("GUSD")
HNT = Coin("HNT")
HOT = Coin("HOT")
HUSD = Coin("HUSD")
ICP = Coin("ICP")
ICX = Coin("ICX")
ILV = Coin("ILV")
INJ = Coin("INJ")
IQ = Coin("IQ")
KAVA = Coin("KAVA")
KEEP = Coin("KEEP")
KLAY = Coin("KLAY")
KNC = Coin("KNC")
KSM = Coin("KSM")
LINK = Coin("LINK")
LPT = Coin("LPT")
LRC = Coin("LRC")
LTC = Coin("LTC")
LUNA = Coin("LUNA")
MANA = Coin("MANA")
MASK = Coin("MASK")
MATIC = Coin("MATIC")
MCO = Coin("MCO")
MIR = Coin("MIR")
MKR = Coin("MKR")
MLN = Coin("MLN")
NANO = Coin("NANO")
NEAR = Coin("NEAR")
NEO = Coin("NEO")
NKN = Coin("NKN")
OCEAN = Coin("OCEAN")
OGN = Coin("OGN")
OMG = Coin("OMG")
ONE = Coin("ONE")
ONEINCH = Coin("1INCH")
ONT = Coin("ONT")
PAXG = Coin("PAXG")
PENDLE = Coin("PENDLE")
PLA = Coin("PLA")
POLY = Coin("POLY")
QNT = Coin("QNT")
QTUM = Coin("QTUM")
QUICK = Coin("QUICK")
RAD = Coin("RAD")
RARI = Coin("RARI")
REN = Coin("REN")
RLC = Coin("RLC")
RLY = Coin("RLY")
RSR = Coin("RSR")
RUNE = Coin("RUNE")
RVN = Coin("RVN")
SAND = Coin("SAND")
SC = Coin("SC")
SHIB = Coin("SHIB")
SKL = Coin("SKL")
SLP = Coin("SLP")
SNX = Coin("SNX")
SOL = Coin("SOL")
STORJ = Coin("STORJ")
STX = Coin("STX")
SUSHI = Coin("SUSHI")
TFUEL = Coin("TFUEL")
THETA = Coin("THETA")
TRB = Coin("TRB")
TUSD = Coin("TUSD")
UMA = Coin("UMA")
UNI = Coin("UNI")
USDC = Coin("USDC")
USDP = Coin("USDP")
USDT = Coin("USDT")
VET = Coin("VET")
VTHO = Coin("VTHO")
WAVE = Coin("WAVE")
WAVES = Coin("WAVES")
WBTC = Coin("WBTC")
XLM = Coin("XLM")
XRP = Coin("XRP")
XTZ = Coin("XTZ")
YFI = Coin("YFI")
YGG = Coin("YGG")
ZIL = Coin("ZIL")
ZRX = Coin("ZRX")


def all():
    return [
        value for name, value in globals().items()
        if isinstance(value, Coin)
    ]
